# Online Experiments To Collect AutoRA Observations

AutoRA provides functionality for running closed-loop behavioral studies with online experiments. This functionality allows researchers to set up websites that integrate with AutoRA workflows. These websites allow observations gathered from participants online.

![System Overview](../../examples//img/system_overview.png)

To enable this functionality, AutoRA can interface with databases, such as Firebase for hosting the website and storing data. In addition, AutoRA can recruit participants through platforms like Prolific.

